@@ -10,6 +10,6 @@ colors = Fore
 class coloredPrint():
     def print(self, textToPrint, color=None):
         if (color == None):
-            print(f"{colors.RED}")
+            print(f"{colors.RED}", end="")
             raise ValueError(f"Color can't be None{colors.RESET}")
         print(f"{color}{textToPrint}{colors.RESET}")
